ResetServerHandler

Trait ResetServerHandler 

pub trait ResetServerHandler<___T = Channel>
where ___T: Transport,
{ // Required methods fn assert( &mut self, responder: Responder<Assert, ___T>, ) -> impl Future<Output = ()> + Send; fn deassert( &mut self, responder: Responder<Deassert, ___T>, ) -> impl Future<Output = ()> + Send; fn toggle( &mut self, responder: Responder<Toggle, ___T>, ) -> impl Future<Output = ()> + Send; fn toggle_with_timeout( &mut self, request: Request<ToggleWithTimeout, ___T>, responder: Responder<ToggleWithTimeout, ___T>, ) -> impl Future<Output = ()> + Send; fn status( &mut self, responder: Responder<Status, ___T>, ) -> impl Future<Output = ()> + Send; // Provided method fn on_unknown_interaction( &mut self, ordinal: u64, ) -> impl Future<Output = ()> + Send { ... } }
A server handler for the Reset protocol.

See Reset for more details.

Required Methods

fn assert( &mut self, responder: Responder<Assert, ___T>, ) -> impl Future<Output = ()> + Send

Asserts the reset pin and leaves it asserted until Deassert is called.

fn deassert( &mut self, responder: Responder<Deassert, ___T>, ) -> impl Future<Output = ()> + Send

Deasserts the reset pin.

fn toggle( &mut self, responder: Responder<Toggle, ___T>, ) -> impl Future<Output = ()> + Send

These methods assert the pin, wait a predetermined amount of time, and then deassert the pin. The difference between Toggle and ToggleWithTimeout is that Toggle defers to the Reset driver to choose the timeout duration and ToggleWithTimeout allows the client to specify the timeout.

fn toggle_with_timeout( &mut self, request: Request<ToggleWithTimeout, ___T>, responder: Responder<ToggleWithTimeout, ___T>, ) -> impl Future<Output = ()> + Send

fn status( &mut self, responder: Responder<Status, ___T>, ) -> impl Future<Output = ()> + Send

Provided Methods

fn on_unknown_interaction( &mut self, ordinal: u64, ) -> impl Future<Output = ()> + Send

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors